///
/// @file
/// Declares macros for the whereami library version.
///
#pragma once

///
/// The whereami library major version.
///
#define WHEREAMI_VERSION_MAJOR 0
///
/// The whereami library minor version.
///
#define WHEREAMI_VERSION_MINOR 5
///
/// The whereami library patch version.
///
#define WHEREAMI_VERSION_PATCH 0

///
/// The whereami library version as a string (without commit SHA1).
///
#define WHEREAMI_VERSION "0.5.0"

///
/// The whereami library version as a string (with commit SHA1).
///
#define WHEREAMI_VERSION_WITH_COMMIT "0.5.0"
